import { BrowserBridge } from '../core/bridge';
import { Query, QueryConfiguration } from '../core/query';
import { SelectedRangeRefinement, SelectedValueRefinement, Sort } from '../models/request';
import { Navigation, RefinementResults, Results } from '../models/response';
import { Pager } from './pager';
import EventEmitter = require('eventemitter3');
export declare namespace Events {
    const SEARCH: string;
    const RESULTS: string;
    const REFINEMENT_RESULTS: string;
    const REFINEMENTS_CHANGED: string;
    const PAGE_CHANGED: string;
    const QUERY_CHANGED: string;
    const RESET: string;
    const REWRITE_QUERY: string;
    const SORT: string;
    const DETAILS: string;
    const REDIRECT: string;
}
export { Pager };
export declare type FluxRefinement = SelectedValueRefinement | SelectedRangeRefinement;
export interface FluxConfiguration extends QueryConfiguration {
    bridge?: {
        headers?: any;
        https?: boolean;
        timeout?: number;
    };
}
export declare class FluxCapacitor extends EventEmitter {
    query: Query;
    bridge: BrowserBridge;
    results: Results;
    page: Pager;
    private originalQuery;
    constructor(endpoint: string, config?: FluxConfiguration, mask?: string);
    search(originalQuery?: string): Promise<Results>;
    refinements(navigationName: string): Promise<RefinementResults>;
    rewrite(query: string, config?: RewriteConfig): Promise<string>;
    resetRecall(): void;
    reset(query?: string): Promise<string>;
    resize(pageSize: number, offset?: number): Promise<number>;
    sort(sort: Sort, clearSorts?: Sort[]): Promise<Results>;
    refine(refinement: FluxRefinement, config?: RefinementConfig): Promise<NavigationInfo>;
    unrefine(refinement: FluxRefinement, config?: RefinementConfig): Promise<NavigationInfo>;
    details(id: string): Promise<Results>;
    switchCollection(collection: string): Promise<Results>;
    private emitQueryChanged(query);
    private readonly filteredRequest;
    private resetPaging(reset);
    private doRefinement({reset});
    private readonly navigationInfo;
}
export interface NavigationInfo {
    available: Navigation[];
    selected: Navigation[];
}
export interface RefinementConfig {
    reset?: boolean;
    skipSearch?: boolean;
}
export interface RewriteConfig {
    skipSearch?: boolean;
}
